<?xml version='1.0' encoding="utf-8"?>
<!-- $Id: publidoc2epub3_template.inc.xsl 5dd54c82d91f 2015/05/21 14:56:01 Patrick $ -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:date="http://exslt.org/dates-and-times"
                extension-element-prefixes="date">

  <!--
      =========================================================================
      Template html_file
      =========================================================================
  -->
  <xsl:template name="html_file">
    <xsl:param name="name"/>
    <xsl:param name="title"/>
    <xsl:param name="nojs"/>
    <xsl:param name="body"/>
    <xsl:document href="{$path}{$name}{$html_ext}" method="xml"
                  encoding="utf-8" indent="yes">
      <xsl:call-template name="html_frame">
        <xsl:with-param name="title" select="$title"/>
        <xsl:with-param name="nojs" select="$nojs"/>
        <xsl:with-param name="body" select="$body"/>
      </xsl:call-template>
    </xsl:document>
  </xsl:template>

  <!--
      =========================================================================
      Template html_frame
      =========================================================================
  -->
  <xsl:template name="html_frame">
    <xsl:param name="title"/>
    <xsl:param name="nojs"/>
    <xsl:param name="body"/>
    <xsl:text disable-output-escaping="yes">&lt;!DOCTYPE html&gt;
</xsl:text>
    <xsl:comment> Generated by PubliForge, <xsl:value-of select="date:date-time()"/> </xsl:comment>
    <html xmlns="http://www.w3.org/1999/xhtml">
      <xsl:attribute name="xml:lang"><xsl:value-of select="$lang"/></xsl:attribute>
      <xsl:attribute name="lang"><xsl:value-of select="$lang"/></xsl:attribute>
      <head>
        <meta charset="utf-8"/>
        <title><xsl:value-of select="$title"/></title>
        <xsl:choose>
          <xsl:when test="$minify">
            <link rel="StyleSheet" href="{$css_dir}styles.css" type="text/css"/>
            <xsl:if test="$js and (not($nojs) or $onefile)">
              <script src="{$js_dir}jquery.js" type="text/javascript"><xsl:text> </xsl:text></script>
              <script src="{$js_dir}scripts.js" type="text/javascript"><xsl:text> </xsl:text></script>
            </xsl:if>
          </xsl:when>
          <xsl:otherwise>
            <xsl:if test="not(@type) or @type!='image'
                          or count(.//section)&gt;1 or count(section/media)!=1
                          or count(.//p)&gt;0 or count(.//hotspot)&gt;0
                          or count(.//caption)&gt;0">
              <link rel="StyleSheet" href="{$css_dir}publidoc.css" type="text/css"/>
            </xsl:if>
            <link rel="stylesheet" href="{$css_dir}custom.css" type="text/css"/>
            <xsl:if test="$js and (not($nojs) or $onefile)">
              <script src="{$js_dir}jquery.js" type="text/javascript"><xsl:text> </xsl:text></script>
              <xsl:if test="$aud and $aud_custom">
                <script src="{$js_dir}audio_player.js" type="text/javascript"><xsl:text> </xsl:text></script>
              </xsl:if>
              <script src="{$js_dir}publidoc.js" type="text/javascript"><xsl:text> </xsl:text></script>
            </xsl:if>
          </xsl:otherwise>
        </xsl:choose>
      </head>
      <xsl:copy-of select="$body"/>
    </html>
  </xsl:template>

  <!--
      =========================================================================
      Template minify_files
      =========================================================================
  -->
  <xsl:template name="minify_files">
    <xsl:if test="$minify">
      <xsl:document
          href="{$path}{$css_dir}styles.css" method="text" encoding="utf-8">
publidoc.css
custom.css
      </xsl:document>
      <xsl:if test="$js">
        <xsl:document
            href="{$path}{$js_dir}scripts.js" method="text" encoding="utf-8">
<xsl:if test="$aud and $aud_custom">
audio_player.js
</xsl:if>
publidoc.js
        </xsl:document>
      </xsl:if>
    </xsl:if>
  </xsl:template>

  <!--
      =========================================================================
      Template identifier
      =========================================================================
  -->
  <xsl:template name="identifier">
    <xsl:choose>
      <xsl:when test="$ean">
        <xsl:value-of select="$ean"/>
      </xsl:when>
      <xsl:when test="head/identifier[@type='ean' and @for='epub3']">
        <xsl:value-of select="head/identifier[@type='ean' and @for='epub3']"/>
      </xsl:when>
      <xsl:when test="head/identifier[@type='ean' and @for='epub']">
        <xsl:value-of select="head/identifier[@type='ean' and @for='epub']"/>
      </xsl:when>
      <xsl:when test="head/identifier[@type='ean' and not(@for)]">
        <xsl:value-of select="head/identifier[@type='ean' and not(@for)]"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:choose>
          <xsl:when test="$publisher_url"><xsl:value-of select="$publisher_url"/></xsl:when>
          <xsl:when test="head/contributors/contributor[role='publisher']/link/@uri">
            <xsl:value-of select="head/contributors/contributor[role='publisher']/link/@uri"/>
          </xsl:when>
          <xsl:otherwise>http://www.publiforge.org</xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="concat('/epub/', @id)"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

</xsl:stylesheet>
