<?xml version='1.0' encoding="utf-8"?>
<!-- $Id: publiquiz2epub3_template.inc.xsl 64ce0a62af09 2015/12/02 14:47:48 Coraline $ -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:date="http://exslt.org/dates-and-times"
                extension-element-prefixes="date">

  <!--
      =========================================================================
      Template html_frame
      =========================================================================
  -->
  <xsl:template name="html_frame">
    <xsl:param name="title"/>
    <xsl:param name="nojs"/>
    <xsl:param name="body"/>
    <xsl:text disable-output-escaping="yes">&lt;!DOCTYPE html&gt;
</xsl:text>
    <xsl:comment> Generated by PubliForge, <xsl:value-of select="date:date-time()"/> </xsl:comment>
    <html xmlns="http://www.w3.org/1999/xhtml">
      <xsl:attribute name="xml:lang"><xsl:value-of select="$lang"/></xsl:attribute>
      <xsl:attribute name="lang"><xsl:value-of select="$lang"/></xsl:attribute>
      <head>
        <meta charset="utf-8"/>
        <title><xsl:value-of select="$title"/></title>
        <xsl:choose>
          <xsl:when test="$minify">
            <link rel="StyleSheet" href="{$css_dir}styles.css" type="text/css"/>
            <xsl:if test="not($nojs) or $onefile">
              <script src="{$js_dir}jquery.js" type="text/javascript"><xsl:text> </xsl:text></script>
              <script src="{$js_dir}scripts.js" type="text/javascript"><xsl:text> </xsl:text></script>
            </xsl:if>
          </xsl:when>
          <xsl:otherwise>
            <xsl:if test="not(@type) or @type!='image'
                          or count(.//section)&gt;1 or count(section/media)!=1
                          or count(.//p)&gt;0 or count(.//hotspot)&gt;0
                          or count(.//caption)&gt;0">
              <link rel="StyleSheet" href="{$css_dir}publidoc.css" type="text/css"/>
            </xsl:if>
            <link rel="stylesheet" href="{$css_dir}publiquiz.css" type="text/css"/>
            <link rel="stylesheet" href="{$css_dir}custom.css" type="text/css"/>
            <xsl:if test="not($nojs) or $onefile">
              <script src="{$js_dir}jquery.js" type="text/javascript"><xsl:text> </xsl:text></script>
              <xsl:if test="$aud and $aud_custom">
                <script src="{$js_dir}audio_player.js" type="text/javascript"><xsl:text> </xsl:text></script>
              </xsl:if>
              <script src="{$js_dir}publidoc.js" type="text/javascript"><xsl:text> </xsl:text></script>
              <xsl:if test="name()='quiz'">
                <script src="{$js_dir}publiquiz.js" type="text/javascript"><xsl:text> </xsl:text></script>
                <script src="{$js_dir}publiquiz_basics.js" type="text/javascript"><xsl:text> </xsl:text></script>
                <xsl:if test="$matching_link">
                  <script src="{$js_dir}publiquiz_matching_link.js" type="text/javascript"><xsl:text> </xsl:text></script>
                </xsl:if>
                <xsl:if test="$mip">
                  <script src="{$js_dir}publiquiz_mip.js" type="text/javascript"><xsl:text> </xsl:text></script>
                </xsl:if>
                <script src="{$js_dir}publiquiz_loader.js" type="text/javascript"><xsl:text> </xsl:text></script>
              </xsl:if>
            </xsl:if>
          </xsl:otherwise>
        </xsl:choose>
      </head>
      <xsl:copy-of select="$body"/>
    </html>
  </xsl:template>

  <!--
      =========================================================================
      Template minify_files
      =========================================================================
  -->
  <xsl:template name="minify_files">
    <xsl:if test="$minify">
      <xsl:document
          href="{$path}{$css_dir}styles.css" method="text" encoding="utf-8">
publidoc.css
publiquiz.css
custom.css
      </xsl:document>
      <xsl:document
          href="{$path}{$js_dir}scripts.js" method="text" encoding="utf-8">
<xsl:if test="$aud and $aud_custom">
audio_player.js
</xsl:if>
publidoc.js
publiquiz.js
publiquiz_basics.js
<xsl:if test="$matching_link">
publiquiz_matching_link.js
</xsl:if>
<xsl:if test="$mip">
publiquiz_mip.js
</xsl:if>
publiquiz_loader.js
        </xsl:document>
      </xsl:if>
  </xsl:template>

  <!--
      =========================================================================
      Template anchor_levels
      =========================================================================
  -->
  <xsl:template name="anchor_levels">
    <div>
      <a id="level1"><xsl:text> </xsl:text></a>
      <a id="level2"><xsl:text> </xsl:text></a>
      <a id="level3"><xsl:text> </xsl:text></a>
      <a id="level4"><xsl:text> </xsl:text></a>
      <a id="level5"><xsl:text> </xsl:text></a>
    </div>
  </xsl:template>

  <!--
      =========================================================================
      Template toc
      =========================================================================
  -->
  <xsl:template name="toc">
    <xsl:variable name="has_children">
      <xsl:call-template name="has_toc_children"/>
    </xsl:variable>

    <xsl:call-template name="html_file">
      <xsl:with-param name="name" select="concat($fid, '-toc')"/>
      <xsl:with-param name="title" select="$i18n_toc"/>
      <xsl:with-param name="nojs" select="1"/>
      <xsl:with-param name="body">
        <body class="pdocToc">
          <xsl:if test="head/title">
            <div class="h1"><xsl:apply-templates select="head/title"/></div>
          </xsl:if>
          <xsl:if test="$has_children='1'">
            <div class="h2"><xsl:value-of select="$i18n_toc"/></div>
            <ul>
              <xsl:apply-templates
                  select="division|topic|quiz|section" mode="toc"/>
            </ul>
          </xsl:if>
        </body>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

</xsl:stylesheet>
